]> Dogcows Code - chaz/rasterize/blobdiff - scene.h
add external supersampling to animate script
[chaz/rasterize] / scene.h
diff --git a/scene.h b/scene.h
index 7857b76912f2d278b55f9880e564dbf645b698b7..d198614a3b4ee5385bb3a4166f9aa51d54539f3f 100644 (file)
--- a/scene.h
+++ b/scene.h
@@ -5,21 +5,21 @@
  * mcgarvey@eng.utah.edu
  */
 
-#ifndef __SCENE_H__
-#define __SCENE_H__
+#ifndef _SCENE_H_
+#define _SCENE_H_
 
-#include "pixmap.h"
+#include "raster.h"
 
 
 /*
- * A scene.
+ * A scene class.
  */
 typedef struct scene scene_t;
 
 /*
  * Allocate a scene by reading in data from a file.
  */
-scene_t* scene_alloc(const char* filename);
+scene_t* scene_alloc(FILE* file);
 
 /*
  * Destroy a scene.
@@ -28,11 +28,11 @@ void scene_destroy(scene_t* s);
 
 
 /*
* Render a scene to an in-memory pixmap.  The caller takes ownership of the
  * returned object and must destroy it when it is no longer needed.
  */
-pixmap_t* scene_render(scene_t* s);
+raster_t* scene_render(scene_t* s);
 
 
-#endif // __SCENE_H__
+#endif // _SCENE_H_
 
This page took 0.022343 seconds and 4 git commands to generate.
@@ -28,11 +28,11 @@ void scene_destroy(scene_t* s);
 
 /*
- * Render a scene to an in-memory pixmap.  The caller takes ownership of the
+ * Render a scene to an in-memory raster.  The caller takes ownership of the
  * returned object and must destroy it when it is no longer needed.
  */